#!/bin/sh
#
# This program is released under the terms of the GNU General Public
# License
# (GPL), which is distributed with this software in the the file "COPYING".
# The GPL specifies the terms under which users may copy and use this
# software.
#
#
# ubuntuinstall.sh
# script to help with installing PBNJ on Ubuntu Liinux or any Unix machine
# Author:            Joshua D. Abraham
# Created :          December 11, 2005
# Version:           1.0
#

ubuntuInstall() {
    if test `uname -s` == "Linux" -a -e /etc/lsb-release; then
	    source /etc/lsb-release
	    if test "$DISTRIB_ID" == "Ubuntu" ; then
		    echo "Installing the modules needed for PBNJ"
		    sudo apt-get install libtext-diff-perl \
		    liblist-moreutils-perl libmime-lite-perl
            if test $? -ne 0 ; then 
                echo "Couldn't find one of the module packages in apt"
                nonUbuntuInstall
            fi
            
            echo "Building makefile [ perl Makefile.PL ] ..."
            perl Makefile.PL
		    if test $? -ne 0 ; then
                echo "error while building makefile"
            else     
                echo "ok"
            fi
            
            echo "Building makefile [ make ] ..."
		    make 
		    if test $? -ne 0 ; then 
			    echo "make error"
		        error
            else
                echo "ok"
            fi
            
            echo "Running Tests [ make test ] ..."
            make test
		    if test $? -ne 0 ; then 
		        echo "Didn't pass all the tests"
			    error
            else
                echo "ok" 
            fi
            
		    echo "Installing PBNJ [ make install ] ..." 
            sudo make install
		    if test $? -ne 0 ; then
		        echo "Installation Failed"
                error
            else
                echo "ok"
                echo "PBNJ installed"
			    echo "Run man pbnj for details";
                echo -n "Cleaning dir ..."
	        fi	

            echo "Cleaning up dir [ make realclean ] ..."            
            make realclean
            if test $? -ne 0 ; then 
                echo "make realclean error"
                error
            else 
                echo "ok"
            fi
                
        else
            nonUbuntuInstall
        fi
    fi
}

nonUbuntuInstall(){ 
    echo "Here are the modules required for PBNJ"
    echo " - Text::Diff"
    echo " - Text::CSV"
    echo " - List::MoreUtils"
    echo " - FileHandle"
    echo " - MIME::Lite"
    echo "Do you have all the modules installed? [y/n]"
    read MOD
    if test "$MOD" == "y" -o "$MOD" == "yes" ; then
        echo  "Building Makefile [ perl Makefile.PL ] ..."
        perl Makefile.PL
        if test $? -ne 0 ; then 
            echo "Makefile error"
            error
        else 
            echo "ok"
        fi

        echo  "Preparing PBNJ for Install [ make ] ..." 
        make
        if test $? -ne 0 ; then
            echo "make didn't pass"
            error
        else
            echo "ok"
        fi

        echo  "Testing PBNJ for Install [ make test ] ..."
        make test
        if test $? -ne 0 ; then
            echo "All the tests didn't pass"
            error
        else
            echo "ok"
        fi

        echo  "Installing PBNJ [ sudo make install ] ..."
        sudo make install
        if test $? -ne 0 ; then
            echo "Install Failed"
            error
        else 
            echo "ok"
            echo "PBNJ installed"
            echo "Run man pbnj for details";
        fi

        echo  "Cleaning up dir [ make realclean ]..."
        make realclean
        if test $? -ne 0 ; then
            echo "Cleanup  Failed"
            error
        else     
            echo "ok"
        fi

    else 
        echo "Use the directions in the INSTALL file."
        error
    fi
}

# start with Ubuntu Install
ubuntuInstall
